const getCurrentVersion = require('./version');
const { parseArgsToJson } = require('./utils');
const appConfig = require('./appConfig');

const CurrentVersion = getCurrentVersion();

function extendEnv(isHotSsrEnv) {
  const result = {
    REACT_APP_VERSION: CurrentVersion
  };

  if (process.env.NODE_ENV === 'production') {
    return { ...result, ...appConfig.getBuildEnvConfig(parseArgsToJson) };
  }

  if (isHotSsrEnv) {
    return { ...result, ...appConfig.getHotSsrEnvConfig(parseArgsToJson) };
  }

  return { ...result, ...appConfig.getStartEnvConfig(parseArgsToJson) };
}

const REACT_APP = /^REACT_APP_/i;

function getEnvironmentInfo(isHotSsrEnv) {
  const raw = Object.keys(process.env)
    .filter(key => REACT_APP.test(key))
    .reduce(
      (env, key) => {
        env[key] = process.env[key];
        return env;
      },
      {
        NODE_ENV: process.env.NODE_ENV || 'development',
        BABEL_ENV: process.env.BABEL_ENV || 'development',
        ...extendEnv(isHotSsrEnv)
      }
    );
  // DefinePlugin
  const stringified = {
    'process.env': Object.keys(raw).reduce((env, key) => {
      env[key] = JSON.stringify(raw[key]);
      return env;
    }, {})
  };
  return { raw, stringified, version: CurrentVersion };
}

module.exports = getEnvironmentInfo;
